﻿using System;
using System.Windows.Forms;
using System.Collections.Specialized;
using Globodox;
using Globodox.ResponseClasses;

namespace itaz_sdk_sample_app
{
    public partial class Form1 : Form
    {

        Api globodoxApi = null;

        public Form1()
        {
            InitializeComponent();            
        }

        private void log(string text)
        {
            string n = System.Environment.NewLine;
            txbResults.AppendText(text + n);
        }


        private void btnGo_Click(object sender, EventArgs e)
        {
            btnGo.Enabled = false;
            
            int addedDocumentID = 0;
            int addedStackItemID = 0;

            string serverURL = txbGlobodoxServer.Text;
            string userName = txbUserName.Text;
            string userPassword = txbPassword.Text;

            //Clear the log box
            txbResults.Text = "";

            try
            {
                InitializeAndLogin(serverURL, userName, userPassword);

                GetDbList();

                GetEntityListForDbId1();

                addedDocumentID = AddDocumentToDBId1();

                DownloadDocumentFromDBID1(addedDocumentID);

                DeleteAddedDocumentFromDBId1(addedDocumentID);

                addedStackItemID = AddItemToContactStackTypeInDb1();

                GetListOfItemsInContactStackTypeInDb1();

                DeleteItemFromContactStackTypeInDB1(addedStackItemID);

            }
            catch (GlobodoxException ex)
            {
                log("ERROR: Code = " + ex.ErrorCode + " Message = " + ex.ErrorMessage);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "ERROR");
            }
            finally
            {
                globodoxApi = null;

                btnGo.Enabled = true;
            }
        }

        private void InitializeAndLogin(string serverUrl, string userName, string userPassword)
        {
            log("Creating object and Logging in...");

            globodoxApi = new Globodox.Api(serverUrl, userName, userPassword, "Sample App");

            log("Logged in");

            System.Threading.Thread.Sleep(1000);
        }

        private void GetDbList()
        {
            log("Fetching DB List...");

            GetDbListResponse dbList = globodoxApi.GetDbList(1, 100);
            
            //List all dbs and their types
            foreach (Database db in dbList.Results)
            {
                log("Found DB called " + db.DisplayName + " of type " + db.Type.Name);
            }
        }

        private void GetEntityListForDbId1()
        {
            log("Fetching list of entities...");

            GetEntityListResponse entityList = globodoxApi.GetEntityList(1, "full");

            foreach (Entity entity in entityList.Results)
            {
                log("Found " + (entity.EntityTypeCode < 2000 ? "Stack Type: " : "Document Type: ") + entity.DisplayName);
            }
        }

        private int AddDocumentToDBId1()
        {
            log("Adding new document...");
            
            AddEntityItemResponse addedDoc = globodoxApi.AddDocument(1, @"sample-docs\Invoice NBT To ACME IN00A17.pdf");

            int result = addedDoc.Results[0].ID;

            log("ID of newly added Document is: " + result);

            return result;
        }

        private void DownloadDocumentFromDBID1(int documentID)
        {
            log("Downloading document...");
            
            string fileName = globodoxApi.DownloadDocument(1, documentID);

            log("Document downloaded to..." + fileName);

            if (MessageBox.Show("Do you want to open the downloaded file in its associated application?", "GLOBODOX SDK", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                // open downloaded file in default application on this system
                System.Diagnostics.Process.Start(fileName);
            }
        }

        private void DeleteAddedDocumentFromDBId1(int documentID)
        {
            log("Deleting document...");
            
            globodoxApi.DeleteDocument(1, documentID);

            log("Document deleted");
        }

        private int AddItemToContactStackTypeInDb1()
        {
            NameValueCollection d1 = new NameValueCollection();
            d1.Add("First Name", "John");
            d1.Add("Last Name", "Smith");
            d1.Add("Email ID", "john@smith.com");
            d1.Add("Phone Number", "1234567890");
            d1.Add("Designation", "Employee");
            d1.Add("Address", "Redmond, USA");

            log("Adding new stack item...");

            AddEntityItemResponse addedStack = globodoxApi.AddStackItem(1, "Contact", d1);

            int result = addedStack.Results[0].ID;

            log("ID of newly added Stack Item is: " + result);

            return result;
        }

        private void GetListOfItemsInContactStackTypeInDb1()
        {
            log("Fetching list of stack items...");
            
            GetEntityItemsResponse entityItems = globodoxApi.GetEntityItems(1, "Contact", "First Name*=John", "full", "", true, 1, 10);

            string s = "";

            foreach (EntityItem e in entityItems.Results)
            {
                s = "";
                foreach (CustomAttribute c in e.CustomAttributes)
                {
                    s = s + c.Name + " = " + c.Value;
                }

                log(s);
            }

        }

        private void ModifyExistingItemOfContactStackTypeInDb1(int stackItemIDToModify)
        {
            NameValueCollection d1 = new NameValueCollection();
            d1.Add("First Name", "John");
            d1.Add("Last Name", "Doe");
            d1.Add("Email ID", "john@doe.com");
            d1.Add("Phone Number", "1122334455");
            d1.Add("Designation", "Staff");
            d1.Add("Address", "LA, USA");

            log("Updating stack item...");

            globodoxApi.UpdateStackItem(1, "Contact", stackItemIDToModify, d1);

            log("Stack item with ID " + stackItemIDToModify.ToString() + " updated");
        }

        private void DeleteItemFromContactStackTypeInDB1(int stackItemIDToDelete)
        {
            log("Deleting document...");

            globodoxApi.DeleteStackItem(1, "Contact", stackItemIDToDelete);

            log("Document deleted.");
        }

        private void Logout()
        {
            log("Logging out...");

            globodoxApi.Logout();
            
            log("Logged out");
        }

        private void label1_Click(object sender, EventArgs e)
        {

        }

        private void label5_Click(object sender, EventArgs e)
        {

        }
    }
}
